Comment Comment by super_tycoon I refactored it to be more static and final/const. Also used an int[][] for the node data.Original comment is on proggit. Went from 1600ms to 900ms.http://pastebin.com/w2BC8fNghttp://www.reddit.com/r/programming/comments/2pvf68/armv7_vs... parent super_tycoon 12 years ago
Original comment is on proggit. Went from 1600ms to 900ms.
http://pastebin.com/w2BC8fNg
http://www.reddit.com/r/programming/comments/2pvf68/armv7_vs...